/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.cropcircle;

import java.util.Arrays;
import java.util.List;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import nl.cloudfarming.client.sensor.SensorProcessorProvider;
import nl.cloudfarming.client.sensor.SensorUtil;
import nl.cloudfarming.client.util.FilePickerUtil;
import org.openide.filesystems.FileObject;
import org.openide.util.NbBundle;
import org.openide.util.lookup.ServiceProvider;

/**
 * Processor for cropcircle data
 * 
 * @author Timon Veenstra
 */
@ServiceProvider(service = SensorProcessorProvider.class)
public class CropcircleProcessorProvider implements SensorProcessorProvider {

    private static final AppLogger LOG = AppLogFactory.getLogger(CropcircleProcessorProvider.class);
    private final String filefilterDescription = NbBundle.getMessage(this.getClass(), "sensor.cropcircle.processorprovider.filefilter.description", FilePickerUtil.getFileFilterTypeString(getSupportedExtentions()));


    @Override
    public List<String> getSupportedExtentions() {
        return Arrays.asList(new String[]{".csv", ".txt"});
    }

    @Override
    public boolean isSupported(FileObject sensorFile) {
        String fileExtension = sensorFile.getName().substring(sensorFile.getName().lastIndexOf("."));

        // 1: Check extension
        if(!getSupportedExtentions().contains(fileExtension.toLowerCase())){
            return false;
        }

        // 2: Check fileheader
        if(!SensorUtil.hasValidHeader(sensorFile, CropcircleASC340FileDescription.values())){
            return false;
        }
        
        // If preceeding code is passed this file is considered supported.
        return true;
    }

    @Override
    public String getFormatDescription() {
        return this.filefilterDescription;
    }
    
    @Override
    public CropcircleFileProcessor getProcessor(FileObject sensorFile) {     
        // Determine which FileProcessor is needed for this cropcircle file
        if(SensorUtil.hasValidHeader(sensorFile, CropcircleASC340FileDescription.values())){
//           return new CropcircleASC340FileProcessor(sensorFile);
        }
        
        String columnMissing = NbBundle.getMessage(CropcircleProcessorProvider.class, "sensor.common.processorprovider.logerror.column_missing", sensorFile.getName());
            
        LOG.warning(columnMissing);
        
        return null;
    }
}
